package com.swago.room.base

import android.graphics.Rect
import android.text.TextUtils
import android.util.Log
import android.view.View
import android.view.ViewGroup
import androidx.constraintlayout.widget.ConstraintLayout
import androidx.fragment.app.activityViewModels
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.gyf.immersionbar.ImmersionBar
import com.liulishuo.okdownload.DownloadListener
import com.liulishuo.okdownload.DownloadTask
import com.liulishuo.okdownload.core.breakpoint.BreakpointInfo
import com.liulishuo.okdownload.core.cause.EndCause
import com.liulishuo.okdownload.core.cause.ResumeFailedCause
import com.swago.baseswago.baseroom.IRoomActiveListener
import com.swago.baseswago.baseroom.IRoomInfo
import com.swago.baseswago.baseroom.RoomTimer
import com.swago.baseswago.baseroom.SwagoRoomManager
import com.swago.baseswago.constant.UrlConstant
import com.swago.baseswago.fragment.BaseXFragment
import com.swago.baseswago.im.IRoomChat
import com.swago.baseswago.model.im.RoomSystemMsgBean
import com.swago.baseswago.util.*
import com.swago.room.R
import com.swago.room.adapter.RoomChatAdapter
import com.swago.room.databinding.FragmentBaseComBinding
import com.swago.room.dialog.MessageListDialog
import com.swago.room.dialog.SendMsgDialog
import com.swago.room.game.GamePlayDialog
import com.swago.room.gift.control.SvgPlayerManager
import com.swago.room.giftdandao.GiftDanDaoManager
import com.swago.room.inter.IFooter
import com.swago.room.inter.IHeader
import com.swago.room.piaotiao.WaftManager
import com.swago.room.vm.MsgVm
import com.swago.room.vm.RoomVm
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.GlobalScope
import kotlinx.coroutines.launch
import java.io.File
import java.lang.Exception
import java.util.concurrent.CopyOnWriteArrayList

/**
 *@date 2021/10/8 16:43
 *description:
 */
abstract class BaseComFragment<T : FragmentBaseComBinding> : BaseXFragment<T>(),
    IRoomActiveListener,
    RoomTimer.TimeTickListener {

    val roomVm by activityViewModels<RoomVm>()
    val msgVm by activityViewModels<MsgVm>()

    abstract val iHeader: IHeader
    abstract val iFooter: IFooter

    var dialog: SendMsgDialog? = null
    var gameDialog: GamePlayDialog? = null
    var msgListDialog: MessageListDialog? = null

    private val chatAdapter by lazy {
        RoomChatAdapter()
    }

    private val svgPlayerManager by lazy {
        SvgPlayerManager()
    }

    private val waftManager by lazy {
        WaftManager()
    }

    private val danDaoManager by lazy {
        GiftDanDaoManager()
    }

    private val dataChatList = CopyOnWriteArrayList<IRoomChat>()

    override fun loadData() {

    }

    override fun initOther() {
        RoomTimer.timeTickList.add(this)
        SwagoRoomManager.addListener(this)
        binding.headFl.addView(iHeader.getHeaderView())
        binding.footerFl.addView(iFooter.getFooterView())
        setHeaderViewPosition()
        //飘条
        waftManager.init()
        waftManager.waftViewList.add(binding.waftView)
        waftManager.waftViewList.add(binding.waftView2)
        //弹道
        danDaoManager.init()
        danDaoManager.giftDanDaoViewList.add(binding.danDaoView)
        danDaoManager.giftDanDaoViewList.add(binding.danDaoView2)
        danDaoManager.giftDanDaoViewList.add(binding.danDaoView3)

        val layoutManager = LinearLayoutManager(context)
        layoutManager.stackFromEnd = true
        binding.rv.layoutManager = layoutManager
        binding.rv.addItemDecoration(RoomChatItemDecoration())
        binding.rv.adapter = chatAdapter
        chatAdapter.setNewData(dataChatList)
        context?.let {
            svgPlayerManager.init(it, binding.xSvgaPlayer)
        }

        activity?.let {
            KeyboardUtils.registerSoftInputChangedListener(it.window, listener)
        }
    }

    var listener = KeyboardUtils.OnSoftInputChangedListener {
        if (it == 0) {
            setChatRvPop(false, it)
        } else {
            setChatRvPop(true, it)
        }
    }

    private fun setHeaderViewPosition() {
        val height = ImmersionBar.getStatusBarHeight(this)
        val params = binding.headFl.layoutParams as ConstraintLayout.LayoutParams
        params.topMargin = height
        binding.headFl.layoutParams = params
    }

    override fun initLiveData() {
        msgVm.newChatMsgFun = {
            addChatMsgToRv(it)
        }
        msgVm.playSvgUrl = {
            //svg播放
            svgPlayerManager.addSvgUrl(it)
        }
        //飘条
        msgVm.waftFun = {
            waftManager.addNewMessage(it)
        }
        msgVm.showGiftDanDao = {
            danDaoManager.addNewMessage(it)
        }
    }

    private fun addChatMsgToRv(it: IRoomChat?) {
        if (dataChatList.size > 150) {
            dataChatList.removeAt(0)
        }
        it?.let {
            dataChatList.add(it)
        }
        chatAdapter.notifyDataSetChanged()
        binding.rv.post {
            binding.rv.scrollToPosition(dataChatList.size - 1)
        }
    }


    private var keyboardUpRvLayoutParams: ViewGroup.LayoutParams? = null
    private var keyboardCloseRvLayoutParams: ViewGroup.LayoutParams? = null
    private fun setChatRvPop(isPopUp: Boolean, height: Int) {
        if (isPopUp) {
            if (keyboardUpRvLayoutParams == null) {
                keyboardUpRvLayoutParams =
                    ConstraintLayout.LayoutParams(0, DpPxUtil.dip2px(170f)).apply {
                        bottomToBottom = R.id.cl
                        startToStart = R.id.cl
                        endToEnd = R.id.cl
                        marginStart = DpPxUtil.dip2px(10f)
                        marginEnd = DpPxUtil.dip2px(10f)
                        bottomMargin = height + DpPxUtil.dip2px(55f)
                    }
            }
            binding.rv.layoutParams = keyboardUpRvLayoutParams
        } else {
            if (keyboardCloseRvLayoutParams == null) {
                keyboardCloseRvLayoutParams =
                    ConstraintLayout.LayoutParams(0, DpPxUtil.dip2px(170f)).apply {
                        bottomToBottom = R.id.cl
                        startToStart = R.id.cl
                        endToEnd = R.id.cl
                        marginStart = DpPxUtil.dip2px(10f)
                        marginEnd = DpPxUtil.dip2px(10f)
                        bottomMargin = DpPxUtil.dip2px(70f)
                    }
            }
            binding.rv.layoutParams = keyboardCloseRvLayoutParams
        }

    }


    override fun onDestroyView() {
        super.onDestroyView()
        activity?.let {
            KeyboardUtils.unregisterSoftInputChangedListener(it.window)
        }
        SwagoRoomManager.removeListener(this)
    }

    fun openSendMessageDialog() {
        dialog = SendMsgDialog()
        dialog?.addSenderMsgToRoomChatList = {
            addChatMsgToRv(it)
        }
        dialog?.show(childFragmentManager, "SendMsgDialog")
    }

    fun openMessageListDialog() {
        msgListDialog = MessageListDialog()
        msgListDialog?.show(childFragmentManager, "MessageListDialog")
    }

    fun openGameDialog() {

        SwagoRoomManager.iRoomInfo?.let {
            val download = checkGameVersion(it.getGameType().toString(),it.getGameDownLoadUrl(),it.getGameVersion().toString())
            if (download){
                gameDialog = GamePlayDialog.newInstance("file://" + UrlConstant.appGameRootPath + File.separator + it.getGameType() + File.separator + "index.html")
            }else{
                gameDialog = GamePlayDialog.newInstance(it.getGameUrl())
            }
            gameDialog?.show(childFragmentManager, "GamePlayDialog")
        }
    }

    override fun joinedRoom(iRoomInfo: IRoomInfo) {
        if (iRoomInfo.getRoomSystemMsg().isNotEmpty()){
            val roomSystemMsgBean = RoomSystemMsgBean()
            roomSystemMsgBean.broadcast_notice_content = iRoomInfo.getRoomSystemMsg()
            dataChatList.add(roomSystemMsgBean)
            chatAdapter.notifyDataSetChanged()
        }


    }

    override fun closeRoomed() {
        RoomTimer.timeTickList.remove(this)
    }

    inner class RoomChatItemDecoration : RecyclerView.ItemDecoration() {

        override fun getItemOffsets(
            outRect: Rect,
            view: View,
            parent: RecyclerView,
            state: RecyclerView.State
        ) {
            val margin = DpPxUtil.dip2px(10f)
            outRect.set(0, 0, 0, margin)
        }
    }

    override fun onResume() {
        super.onResume()
        msgVm.isReady = true
    }

    override fun onPause() {
        super.onPause()
        msgVm.isReady = false
    }

    override fun onTimeCount(time: Int) {
        if (time % 30 == 0) {
            SwagoRoomManager.iRoomInfo?.let {
                roomVm.loadRoomData(it.getRoomId())
            }

        }
    }


    private fun checkGameVersion(gameId: String, gamePackageUrl: String, gameVersionCode: String): Boolean {
        if (gamePackageUrl.isEmpty() || gameVersionCode.isEmpty()) {
            return false
        }

        val zipNames = gamePackageUrl.split("/")
        val gameName = zipNames.last()
        if (TextUtils.isEmpty(UrlConstant.appGameRootPath) || !File(UrlConstant.appGameRootPath + File.separator + gameId).exists()) {
            downLoadGamePackage(gameId, gamePackageUrl, gameVersionCode, gameName)
            return false
        } else {
            return if (!File(UrlConstant.appGameRootPath + File.separator + gameId + File.separator + gameName).exists()) {
                downLoadGamePackage(gameId, gamePackageUrl, gameVersionCode, gameName)
                false
            } else {
                val localGameVersionCode = SpUtil.readInt(gameId)
                if (localGameVersionCode == 0 || (gameVersionCode.isNotEmpty() && localGameVersionCode < gameVersionCode.toInt())) {
                    downLoadGamePackage(gameId, gamePackageUrl, gameVersionCode, gameName)
                    false
                } else {
                    true
                }
            }
        }

    }

    private fun downLoadGamePackage(
        gameId: String,
        gamePackageUrl: String,
        gameVersionCode: String,
        name: String
    ) {
        val path = UrlConstant.appGameRootPath + File.separator + gameId
        val file = File(path)
        if (file.exists()) {
            file.delete()
        }
        file.mkdirs()

        val task = DownloadTask.Builder(gamePackageUrl,path,name).build()
        task.enqueue(object:DownloadListener{
            override fun taskStart(task: DownloadTask) {}

            override fun connectTrialStart(
                task: DownloadTask,
                requestHeaderFields: MutableMap<String, MutableList<String>>
            ) {}

            override fun connectTrialEnd(
                task: DownloadTask,
                responseCode: Int,
                responseHeaderFields: MutableMap<String, MutableList<String>>
            ) {}

            override fun downloadFromBeginning(
                task: DownloadTask,
                info: BreakpointInfo,
                cause: ResumeFailedCause
            ) {}

            override fun downloadFromBreakpoint(task: DownloadTask, info: BreakpointInfo) {}

            override fun connectStart(
                task: DownloadTask,
                blockIndex: Int,
                requestHeaderFields: MutableMap<String, MutableList<String>>
            ) {}

            override fun connectEnd(
                task: DownloadTask,
                blockIndex: Int,
                responseCode: Int,
                responseHeaderFields: MutableMap<String, MutableList<String>>
            ) {}

            override fun fetchStart(task: DownloadTask, blockIndex: Int, contentLength: Long) {}

            override fun fetchProgress(task: DownloadTask, blockIndex: Int, increaseBytes: Long) {}

            override fun fetchEnd(task: DownloadTask, blockIndex: Int, contentLength: Long) {}

            override fun taskEnd(task: DownloadTask, cause: EndCause, realCause: Exception?) {
                GlobalScope.launch(Dispatchers.IO) {
                    val packagePath = path + File.separator + name
                    FileUtil.upZipFile(packagePath,path + File.separator)
                    SpUtil.putInt(gameId, gameVersionCode.toInt())
                }
            }

        })
    }

}